# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .text_tone_mark_params import TextToneMarkParams as TextToneMarkParams
from .text_translate_params import TextTranslateParams as TextTranslateParams
from .speech_generate_params import SpeechGenerateParams as SpeechGenerateParams
from .text_tone_mark_response import TextToneMarkResponse as TextToneMarkResponse
from .text_translate_response import TextTranslateResponse as TextTranslateResponse
from .speech_transcribe_params import SpeechTranscribeParams as SpeechTranscribeParams
from .speech_transcribe_response import SpeechTranscribeResponse as SpeechTranscribeResponse
